Type Definition embassy_sync::blocking_mutex::NoopMutex
source · [−]pub type NoopMutex<T> = Mutex<NoopRawMutex, T>;Expand description
A mutex that allows borrowing data in the context of a single executor.
Safety
This Mutex is only safe within a single executor.